@@ -72,12 +72,14 @@ def model_dict_to_str(
 
 
 def basemodel_to_str(
-    model: BaseModelType, default_replace: bool = False
+    model: BaseModelType,
+    default_replace: bool = False,
+    fields_to_exclude: T.Set[str] = None,
 ) -> T.Tuple[str, T.Dict[str, T.Any]]:
     # should exclude_none = True?
     from .resolver import Resolver, UpdateOperation
 
-    model_d = model.dict(exclude_none=True)
+    model_d = model.dict(exclude_none=True, exclude=fields_to_exclude)
 
     set_links_d = {}
     for field_name in model.__fields__.keys():
@@ -219,6 +221,13 @@ class Node(BaseModel, T.Generic[InsertType]):
         if custom_on_conflict_str:
             conflict_str = custom_on_conflict_str
         elif upsert_given_conflict_on:
+            # replace s and variables
+            s, variables = basemodel_to_str(
+                insert,
+                default_replace=True,
+                fields_to_exclude=set(insert.dict(exclude_none=True).keys())
+                - cls.GraphORM.updatable_fields,
+            )
             conflict_str = f"UNLESS CONFLICT ON .{upsert_given_conflict_on} ELSE (UPDATE {cls._model_name} SET {s})"
         elif return_conflicting_model_on:
             conflict_str = f"UNLESS CONFLICT ON .{return_conflicting_model_on} ELSE (SELECT {cls._model_name})"
